/**
 * @name laravel-elixir-sassdoc
 * @author Shane Hendrix
 *
 * @desc Generate documentation for SASS files
 *
 * {@link https://github.com/SassDoc/sassdoc link}
 *
 * @requires sassdoc
 */

/*global require */

var path = require('path');
var gulp    = require('gulp'),
    Elixir  = require('laravel-elixir'),
    sassdoc = require('sassdoc');


/*
 |----------------------------------------------------------------
 | SASSDOC
 |----------------------------------------------------------------
 |
 | This task triggers the SASSDOC software and shows
 | notifications depending on the success or the
 | failure of the SASSDOC via elixir software
 |
 */

Elixir.extend('sassdoc', function initSASSDOC (src, options) {
    'use strict';
    
    var defaultDest = './storage/reports/sassdoc';

    // CHECK:       Options is set
    if ( options === undefined) {
        options = {};
    }     
    // CHECK:       Destination
    if ( options.dest === undefined) {
        options.dest = defaultDest;
    }
    
    
    return gulp
        .src(src || Elixir.config.get('assets.css.sass.folder') + '/**/*.scss')
        .pipe(sassdoc(options))
        .on('error', function(e) {
            new Elixir.Notification().error(e, 'SASSDOC error!');
            this.emit('end');
        })
        .pipe(new Elixir.Notification('SASSDOC complete'))
        .resume()
        ;
});
